@@ -54,18 +54,18 @@ yread <- function(file, reader = readLines, params = list(),
     }
 }
 
-##' read clipboard
-##'
-##'
-##' @title read.cb
-##' @param reader function to read the clipboard
-##' @param ... parameters for the reader
-##' @return clipboard content, output type depends on the output of the reader
-##' @author Guangchuang Yu
-##' @importFrom utils read.table
-##' @export
+#' read clipboard
+#'
+#'
+#' @title read.cb
+#' @param reader function to read the clipboard
+#' @param ... parameters for the reader
+#' @return clipboard content, output type depends on the output of the reader
+#' @author Guangchuang Yu
+#' @importFrom utils read.table
+#' @export
 read.cb <- function(reader = read.table, ...) {
-    os <- Sys.info()[1]
+    os <- which_os()
     if (os == "Darwin") {
         clip <- pipe("pbpaste")
     } else {
@@ -75,22 +75,22 @@ read.cb <- function(reader = read.table, ...) {
 }
 
 
-##' open selected directory or file
-##'
-##'
-##' @title o
-##' @param file to be open; open working directory by default
-##' @return No return value, called for opening specific directory or file
-##' @examples
-##' \dontrun{
-##' ## to open current working directory
-##' o()
-##' }
-##' @export
-##' @author Guangchuang Yu
+#' open selected directory or file
+#'
+#'
+#' @title o
+#' @param file to be open; open working directory by default
+#' @return No return value, called for opening specific directory or file
+#' @examples
+#' \dontrun{
+#' ## to open current working directory
+#' o()
+#' }
+#' @export
+#' @author Guangchuang Yu
 o <- function(file=".") {
     file <- normalizePath(file)
-    os <- Sys.info()[1]
+    os <- which_os()
     if (is.rserver()) {
         if (dir.exists(file)) {
             stop("open directory in RStudio Server is not supported.")
@@ -99,7 +99,7 @@ o <- function(file=".") {
         if (!is.null(rserver_ip)) {
             rserver_port <- getOption("rserver_port") %||% '8787' 
             if (!startsWith(rserver_ip, "http")) {
-                rserver_ip = paste0("http://", rserver_ip)
+                rserver_ip <- paste0("http://", rserver_ip)
             }
             utils::browseURL(
                        paste0(
@@ -128,20 +128,20 @@ o <- function(file=".") {
 
 
 is.rserver <- function(){
-    RStudio.Version = tryCatch(get("RStudio.Version"), error = function(e) NULL)
+    RStudio.Version <- tryCatch(get("RStudio.Version"), error = function(e) NULL)
     if(is.null(RStudio.Version)) return(FALSE)
     if(!is.function(RStudio.Version)) return(FALSE)
     RStudio.Version()$mode == 'server'
 }
 
-##' Open data frame in Excel. It can be used in pipe.
-##'
-##'
-##' @title show_in_excel
-##' @param .data a data frame to be open
-##' @return original .data
-##' @export
-##' @author Guangchuang Yu
+#' Open data frame in Excel. It can be used in pipe.
+#'
+#'
+#' @title show_in_excel
+#' @param .data a data frame to be open
+#' @return original .data
+#' @export
+#' @author Guangchuang Yu
 show_in_excel <- function(.data) {
     f <- tempfile(fileext = '.csv')
     utils::write.csv(.data, file=f)
